MethodChannelWeiboKit class

An implementation of WeiboKitPlatform that uses method channels.

Inheritance

Constructors

MethodChannelWeiboKit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth({required String appKey, required List<String> scope, String redirectUrl = WeiboRegister.DEFAULT_REDIRECTURL}) → Future<void>
登录
override
isInstalled() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerApp({required String appKey, required String? universalLink, required List<String> scope, String redirectUrl = WeiboRegister.DEFAULT_REDIRECTURL}) → Future<void>
override
respStream() → Stream<BaseResp>
override
shareImage({String? text, Uint8List? imageData, Uri? imageUri}) → Future<void>
分享 - 图片
override
shareText({required String text}) → Future<void>
分享 - 文本
override
shareWebpage({required String title, required String description, required Uint8List thumbData, required String webpageUrl}) → Future<void>
分享 - 网页
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited