WeiboKitPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WeiboKitPlatform
Implementers

Constructors

WeiboKitPlatform()
Constructs a WeiboKitPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth({required String appKey, required List<String> scope, String redirectUrl = WeiboRegister.DEFAULT_REDIRECTURL}) → Future<void>
登录
isInstalled() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerApp({required String appKey, required String? universalLink, required List<String> scope, String redirectUrl = WeiboRegister.DEFAULT_REDIRECTURL}) → Future<void>
respStream() → Stream<BaseResp>
shareImage({String? text, Uint8List? imageData, Uri? imageUri}) → Future<void>
分享 - 图片
shareText({required String text}) → Future<void>
分享 - 文本
shareWebpage({required String title, required String description, required Uint8List thumbData, required String webpageUrl}) → Future<void>
分享 - 网页
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ WeiboKitPlatform
The default instance of WeiboKitPlatform to use.
getter/setter pair